Documentation
¶
Overview ¶
pkg/cli.go
Index ¶
- func AuditEndpoints(timeoutCtx context.Context, targetURLs []string, headers map[string]string, ...)
- func DisplayLogo()
- func GenerateAndPrintOperations(generateFn func(*types.GQLSchema, string, int) (string, error), ...)
- func HandleSchemaFile(filePath, listOption, queryOption, mutationOption string, ...)
- func PrintAvailableOperations(schemaObj *types.GQLSchema, listOption string)
- func SetupSignalHandler(parent context.Context) (context.Context, context.CancelFunc)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AuditEndpoints ¶
func AuditEndpoints(timeoutCtx context.Context, targetURLs []string, headers map[string]string, outputFile string)
AuditEndpoints checks each target URL for introspection and writes the results to file.
func DisplayLogo ¶
func DisplayLogo()
func HandleSchemaFile ¶
func HandleSchemaFile(filePath, listOption, queryOption, mutationOption string, allQueries, allMutations bool, maxDepth int)
HandleSchemaFile processes an introspection JSON file and handles schema-related operations.
func PrintAvailableOperations ¶
PrintAvailableOperations prints the names of queries and/or mutations in the schema.
func SetupSignalHandler ¶
SetupSignalHandler creates a cancellable context and registers a signal handler for graceful shutdown. It returns the new context and its cancel function.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.